@@ -4,12 +4,13 @@ from jaaql.utilities.vault import Vault, DIR__vault
 from jaaql.db.db_interface import DBInterface
 import jaaql.utilities.crypt_utils as crypt_utils
 from jaaql.migrations.migrations import run_migrations
-from jaaql.email.email_manager import EmailManager
 from jaaql.db.db_utils import execute_supplied_statement, create_interface
-
 from jaaql.constants import *
+from jaaql.utilities.options import OPT_KEY__canned_queries
 from jaaql.config_constants import *
 from os.path import dirname
+from jaaql.services.cached_canned_query_service import CachedCannedQueryService
+import threading
 
 import uuid
 import traceback
@@ -121,6 +122,22 @@ class BaseJAAQLModel:
             time.sleep(1)
             os._exit(0)
 
+    def group(self, data: [dict], key_field_name: str):
+        outer_dict = {}
+
+        for itm in data:
+            list_itm = [vals for _, vals in itm.items() if isinstance(vals, list)]
+            val_itm = [key for key, val in itm.items() if key != key_field_name]
+            if len(list_itm) == 0:
+                if len(val_itm) == 1:
+                    outer_dict[itm[key_field_name]] = itm[val_itm[0]]
+                else:
+                    outer_dict[itm[key_field_name]] = {key: itm[key] for key in val_itm}
+            else:
+                outer_dict[itm[key_field_name]] = self.group(list_itm[0], key_field_name)
+
+        return outer_dict
+
     def pivot(self, data: [dict], pivot_info: [JAAQLPivotInfo]):
         if len(data) == 0:
             return data
@@ -170,50 +187,47 @@ class BaseJAAQLModel:
         if self.vault.has_obj(VAULT_KEY__jaaql_lookup_connection):
             jaaql_uri = self.vault.get_obj(VAULT_KEY__jaaql_lookup_connection)
             address, port, db, username, password = DBInterface.fracture_uri(jaaql_uri)
-            self.jaaql_lookup_connection = create_interface(self.config, address, port, db, username, password, is_jaaql_user=True)
+            self.jaaql_lookup_connection = create_interface(self.config, address, port, db, username, password=password)
+            if self.options.get(OPT_KEY__canned_queries) or os.environ.get(ENVIRON__canned_queries) == "TRUE":
+                self.cached_canned_query_service = CachedCannedQueryService(self.is_container, self.jaaql_lookup_connection)
 
-    def __init__(self, config, vault_key: str, migration_db_interface=None, migration_project_name: str = None,
+    def __init__(self, config, vault_key: str, options: dict, migration_project_name: str = None,
                  migration_folder: str = None, is_container: bool = False, url: str = None):
         self.config = config
-        self.migration_db_interface = migration_db_interface
         self.migration_project_name = migration_project_name
         self.migration_folder = migration_folder
         self.is_container = is_container
 
+        self.cached_canned_query_service = None
+
         self.url = url
         self.has_installed = False
 
         self.force_mfa = config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__force_mfa]
         self.do_audit = config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__do_audit]
-        self.invite_only = config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__invite_only]
 
         self.vault = Vault(vault_key, DIR__vault)
         self.jaaql_lookup_connection = None
         self.email_manager = None
 
+        self.options = options
+
         self.token_expiry_ms = int(config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__token_expiry_ms])
         self.refresh_expiry_ms = int(config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__token_refresh_expiry_ms])
 
         if not self.vault.has_obj(VAULT_KEY__db_repeatable_salt):
-            salt = os.environ.get("JAAQL_VAULT_SALT", crypt_utils.fetch_random_readable_salt().decode(crypt_utils.ENCODING__ascii))
-            self.vault.insert_obj(VAULT_KEY__db_repeatable_salt, salt)
+            self.vault.insert_obj(VAULT_KEY__db_repeatable_salt, crypt_utils.fetch_random_readable_salt().decode(crypt_utils.ENCODING__ascii))
 
         if not self.vault.has_obj(VAULT_KEY__db_crypt_key):
-            db_crypt_key = os.environ.get("JAAQL_DB_CRYPT_KEY")
-            if not db_crypt_key:
-                _, db_crypt_key = crypt_utils.key_stretcher(str(uuid.uuid4()), length=crypt_utils.AES__key_length)
+            _, db_crypt_key = crypt_utils.key_stretcher(str(uuid.uuid4()), length=crypt_utils.AES__key_length)
             self.vault.insert_obj(VAULT_KEY__db_crypt_key, db_crypt_key.decode(crypt_utils.ENCODING__ascii))
 
         if not self.vault.has_obj(VAULT_KEY__jwt_crypt_key):
-            jwt_crypt_key = os.environ.get("JAAQL_JWT_CRYPT_KEY")
-            if not jwt_crypt_key:
-                _, jwt_crypt_key = crypt_utils.key_stretcher(str(uuid.uuid4()))
+            _, jwt_crypt_key = crypt_utils.key_stretcher(str(uuid.uuid4()))
             self.vault.insert_obj(VAULT_KEY__jwt_crypt_key, jwt_crypt_key.decode(crypt_utils.ENCODING__ascii))
 
         if not self.vault.has_obj(VAULT_KEY__jwt_obj_crypt_key):
-            jwt_obj_crypt_key = os.environ.get("JAAQL_JWT_CRYPT_KEY")
-            if not jwt_obj_crypt_key:
-                _, jwt_obj_crypt_key = crypt_utils.key_stretcher(str(uuid.uuid4()))
+            _, jwt_obj_crypt_key = crypt_utils.key_stretcher(str(uuid.uuid4()))
             self.vault.insert_obj(VAULT_KEY__jwt_obj_crypt_key, jwt_obj_crypt_key.decode(crypt_utils.ENCODING__ascii))
 
         if self.vault.has_obj(VAULT_KEY__jaaql_lookup_connection):
@@ -226,19 +240,21 @@ class BaseJAAQLModel:
             self.has_installed = True
 
         self.set_jaaql_lookup_connection()
+
+        self.reload_lock = threading.Lock()
+
         if self.vault.has_obj(VAULT_KEY__jaaql_lookup_connection):
-            run_migrations(self.jaaql_lookup_connection)
+            run_migrations(self.jaaql_lookup_connection, self.is_container, options=options, key=self.get_db_crypt_key())
 
-            if self.migration_db_interface is None:
-                self.migration_db_interface = self.jaaql_lookup_connection
-
-            run_migrations(self.jaaql_lookup_connection, migration_project_name, migration_folder=migration_folder,
-                           update_db_interface=self.migration_db_interface)
+            if migration_project_name is not None:
+                run_migrations(self.jaaql_lookup_connection, self.is_container, migration_project_name, migration_folder=migration_folder,
+                               config=self.config, super_credentials=self.vault.get_obj(VAULT_KEY__super_db_credentials), options=options,
+                               key=self.get_db_crypt_key())
 
             if self.is_container:
-                self.jaaql_lookup_connection.close(force=True)  # Each individual class will have one
+                self.jaaql_lookup_connection.close()  # Each individual class will have one
 
-            self.email_manager = EmailManager()
+            # self.email_manager = EmailManager(self.is_container)
         else:
             self.install_key = str(uuid.uuid4())
             with open(os.path.join(dirname(dirname(dirname(__file__))), "install_key"), "w") as install_key_file:
@@ -253,8 +269,12 @@ class BaseJAAQLModel:
     def get_db_crypt_key(self):
         return self.vault.get_obj(VAULT_KEY__db_crypt_key).encode(crypt_utils.ENCODING__ascii)
 
-    def get_repeatable_salt(self):
-        return self.vault.get_obj(VAULT_KEY__db_repeatable_salt).encode(crypt_utils.ENCODING__ascii)
+    def get_vault_repeatable_salt(self):
+        return self.vault.get_obj(VAULT_KEY__db_repeatable_salt)
+
+    def get_repeatable_salt(self, addition: str = None):
+        repeatable = self.vault.get_obj(VAULT_KEY__db_repeatable_salt)
+        return crypt_utils.get_repeatable_salt(repeatable, addition)
 
     def setup_paging_parameters(self, inputs: dict, has_deleted: bool = True):
         inputs_no_del = inputs.copy()
