@@ -13,6 +13,7 @@ from cryptography.hazmat.primitives.ciphers import Cipher, algorithms, modes
 from cryptography.hazmat.primitives import padding
 from cryptography.hazmat.backends import default_backend
 from jaaql.constants import ENCODING__ascii
+import hashlib
 
 
 FERNET__key_length = 32
@@ -35,6 +36,13 @@ JWT__algo = "HS256"
 MAX_LONG = 2**63-1
 
 
+def get_repeatable_salt(repeatable: str, addition: str = None):
+    if addition is not None:
+        return hashlib.md5((repeatable + addition).encode(ENCODING__ascii)).digest()
+    else:
+        return repeatable.encode(ENCODING__ascii)
+
+
 def fetch_epoch_ms():
     return int(datetime.now().replace(tzinfo=timezone.utc).timestamp() * 1000)
 
@@ -100,6 +108,13 @@ def encrypt_raw(secret_key: bytes, data: any, iv: bytes = None) -> str:
     return b64e(iv).decode(ENCODING__ascii) + "." + b64e(ct).decode(ENCODING__ascii)
 
 
+def decrypt_raw_ex(secret_key: bytes, data: str) -> str:
+    try:
+        return decrypt_raw(secret_key, data)
+    except Exception as ex:
+        raise Exception("Could not decrypt data. Either key was invalid or data is malformatted")
+
+
 def decrypt_raw(secret_key: bytes, data: str) -> str:
     unpadder = padding.PKCS7(PKCS7__length).unpadder()
     iv = b64d(data.split(".")[0])
